==> nextcloud-22.2.9.tgz: nextcloud/apps/weather_status/l10n/ru.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Неизвестный адрес",
    "No result." : "Нет результатов",
    "Malformed JSON data." : "Неверные данные JSON.",
    "Error" : "Ошибка",
    "Weather status" : "Прогноз погоды",
    "Weather status in your dashboard" : "Виджет для просмотра прогноза погоды",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Текущая погода — виджет для встраивания.\n    Доступен шестичасовой прогноз погоды для выбранного местоположения, которое может быть определено автоматически или указано пользователем.\n Информация о текущей погоде также может быть использована в других приложениях, например, в приложении Календарь.",
    "Detect location" : "Определить местоположение",
    "Set custom address" : "Задать адрес",
    "Favorites" : "Избранное",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} сегодня обещают ясную погоду",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясно",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} сегодня обещают облачно",
    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} сегодня обещают хорошую погоду",
    "{temperature} {unit} fair weather" : "{temperature} {unit} хорошая погода",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} сегодня обещают местами облачно",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} местами облачно",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} сегодня обещают туман",
    "{temperature} {unit} foggy" : "{temperature} {unit} туман",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} ожидается небольшой дождь",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} небольшой дождь",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} ожидается дождь",
    "{temperature} {unit} rainfall" : "{temperature} {unit} дождь",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} ожидается сильный дождь",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} сильный дождь",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} обещают ливневые дожди",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} ливневые дожди",
    "More weather for {adr}" : "Дополнительные сведения о погоде в {adr}",
    "Loading weather" : "Получение сведений о погоде...",
    "Remove from favorites" : "Удалить из избранного",
    "Add as favorite" : "Добавить в избранное",
    "You are not logged in." : "Не выполнен вход в систему.",
    "There was an error getting the weather status information." : "Не удалось получить прогноз погоды.",
    "No weather information found" : "Прогноз погоды не найден",
    "Location not found" : "Местоположение не найдено",
    "There was an error setting the location address." : "Не удалось задать адрес.",
    "There was an error setting the location." : "Не удалось настроить местоположение.",
    "There was an error saving the mode." : "Не удалось сохранить режим.",
    "There was an error using personal address." : "Не удалось использовать личный адрес.",
    "Set location for weather" : "Задать местоположение",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit}, ясно в {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit}, облачно в {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit}, безоблачно в {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit}, безоблачно в {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit}, переменная облачность в {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit}, туман в {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit}, небольшой дождь в {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit}, дождь в {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit}, сильный дождь в {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit}, ливень в {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit}, небольшой ливень в {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit}, сильный ливень в {time}"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-22.2.10.tgz: nextcloud/apps/weather_status/l10n/ru.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Неизвестный адрес",
    "No result." : "Нет результатов",
    "Malformed JSON data." : "Неверные данные JSON.",
    "Error" : "Ошибка",
    "Weather status" : "Прогноз погоды",
    "Weather status in your dashboard" : "Виджет для просмотра прогноза погоды",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Текущая погода — виджет для встраивания.\n    Доступен шестичасовой прогноз погоды для выбранного местоположения, которое может быть определено автоматически или указано пользователем.\n Информация о текущей погоде также может быть использована в других приложениях, например, в приложении Календарь.",
    "Detect location" : "Определить местоположение",
    "Set custom address" : "Задать адрес",
    "Favorites" : "Избранное",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} сегодня обещают ясную погоду",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясно",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} сегодня обещают облачно",
    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} сегодня обещают хорошую погоду",
    "{temperature} {unit} fair weather" : "{temperature} {unit} хорошая погода",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} сегодня обещают местами облачно",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} местами облачно",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} сегодня обещают туман",
    "{temperature} {unit} foggy" : "{temperature} {unit} туман",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} ожидается небольшой дождь",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} небольшой дождь",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} ожидается дождь",
    "{temperature} {unit} rainfall" : "{temperature} {unit} дождь",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} ожидается сильный дождь",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} сильный дождь",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} обещают ливневые дожди",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} ливневые дожди",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} сегодня позже пройдёт небольшой ливневый дождь",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} небольшой ливневый дождь",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} сегодня позже ожидаются сильные проливные дожди",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} сильный проливной дождь",
    "More weather for {adr}" : "Дополнительные сведения о погоде в {adr}",
    "Loading weather" : "Получение сведений о погоде...",
    "Remove from favorites" : "Удалить из избранного",
    "Add as favorite" : "Добавить в избранное",
    "You are not logged in." : "Не выполнен вход в систему.",
    "There was an error getting the weather status information." : "Не удалось получить прогноз погоды.",
    "No weather information found" : "Прогноз погоды не найден",
    "Location not found" : "Местоположение не найдено",
    "There was an error setting the location address." : "Не удалось задать адрес.",
    "There was an error setting the location." : "Не удалось настроить местоположение.",
    "There was an error saving the mode." : "Не удалось сохранить режим.",
    "There was an error using personal address." : "Не удалось использовать личный адрес.",
    "Set location for weather" : "Задать местоположение",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit}, ясно в {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit}, облачно в {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit}, безоблачно в {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit}, безоблачно в {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit}, переменная облачность в {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit}, туман в {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit}, небольшой дождь в {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit}, дождь в {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit}, сильный дождь в {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit}, ливень в {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit}, небольшой ливень в {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit}, сильный ливень в {time}"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
